@@ -5,23 +5,34 @@ TIKTOKEN_MODEL_MAPPING = {
     "gpt-4-1106-preview": "cl100k_base",
     "gpt-4-1106-vision-preview": "cl100k_base",
     "gpt-4o": "0200k_base",
+    "gpt-4o-mini": "0200k_base",
 }
 
 SERVICE_PROVIDERS = {
     "ANTHROPIC": "Anthropic",
     "AZURE": "Azure",
     "CHROMA": "Chroma",
+    "CREWAI": "CrewAI",
+    "DSPY": "DSPy",
     "GROQ": "Groq",
     "LANGCHAIN": "Langchain",
     "LANGCHAIN_COMMUNITY": "Langchain Community",
     "LANGCHAIN_CORE": "Langchain Core",
     "LANGGRAPH": "Langgraph",
+    "LITELLM": "Litellm",
     "LLAMAINDEX": "LlamaIndex",
     "OPENAI": "OpenAI",
     "PINECONE": "Pinecone",
     "COHERE": "Cohere",
     "PPLX": "Perplexity",
     "QDRANT": "Qdrant",
+    "WEAVIATE": "Weaviate",
+    "OLLAMA": "Ollama",
+    "VERTEXAI": "VertexAI",
+    "GEMINI": "Gemini",
+    "MISTRAL": "Mistral",
+    "EMBEDCHAIN": "Embedchain",
+    "AUTOGEN": "Autogen",
 }
 
 LANGTRACE_ADDITIONAL_SPAN_ATTRIBUTES_KEY = "langtrace_additional_attributes"
